diff libpurple/imgstore.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 391a79778f89
line wrap: on
line diff
--- a/libpurple/imgstore.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/imgstore.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file imgstore.h IM Image Store API
  * @ingroup core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -23,11 +23,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
-#ifndef _GAIM_IMGSTORE_H_
-#define _GAIM_IMGSTORE_H_
+#ifndef _PURPLE_IMGSTORE_H_
+#define _PURPLE_IMGSTORE_H_
 
-struct _GaimStoredImage;
-typedef struct _GaimStoredImage GaimStoredImage;
+struct _PurpleStoredImage;
+typedef struct _PurpleStoredImage PurpleStoredImage;
 
 #ifdef __cplusplus
 extern "C" {
@@ -36,7 +36,7 @@
 /**
  * Add an image to the store. The caller owns a reference
  * to the image in the store, and must dereference the image
  * with gaim_imgstore_unref for it to be freed.
  *
  * @param data		Pointer to the image data.
  * @param size		Image data's size.
@@ -44,7 +44,7 @@
 
  * @return ID for the image.
  */
-int gaim_imgstore_add(const void *data, size_t size, const char *filename);
+int purple_imgstore_add(const void *data, size_t size, const char *filename);
 
 /**
  * Retrieve an image from the store. The caller does not own a
@@ -54,7 +54,7 @@
  *
  * @return A pointer to the requested image, or NULL if it was not found.
  */
-GaimStoredImage *gaim_imgstore_get(int id);
+PurpleStoredImage *purple_imgstore_get(int id);
 
 /**
  * Retrieves a pointer to the image's data.
@@ -64,7 +64,7 @@
  * @return A pointer to the data, which must not
  *         be freed or modified.
  */
-gpointer gaim_imgstore_get_data(GaimStoredImage *i);
+gpointer purple_imgstore_get_data(PurpleStoredImage *i);
 
 /**
  * Retrieves the length of the image's data.
@@ -72,9 +72,9 @@
  * @param i	The Image
  *
  * @return The size of the data that the pointer returned by
- *         gaim_imgstore_get_data points to.
+ *         purple_imgstore_get_data points to.
  */
-size_t gaim_imgstore_get_size(GaimStoredImage *i);
+size_t purple_imgstore_get_size(PurpleStoredImage *i);
 
 /**
  * Retrieves a pointer to the image's filename.
@@ -84,7 +84,7 @@
  * @return A pointer to the filename, which must not
  *         be freed or modified.
  */
-const char *gaim_imgstore_get_filename(GaimStoredImage *i);
+const char *purple_imgstore_get_filename(PurpleStoredImage *i);
 
 /**
  * Increment the reference count for an image in the store. The
@@ -93,7 +93,7 @@
  *
  * @param id		The ID for the image.
  */
-void gaim_imgstore_ref(int id);
+void purple_imgstore_ref(int id);
 
 /**
  * Decrement the reference count for an image in the store. The
@@ -102,10 +102,10 @@
  *
  * @param id		The ID for the image.
  */
-void gaim_imgstore_unref(int id);
+void purple_imgstore_unref(int id);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _GAIM_IMGSTORE_H_ */
+#endif /* _PURPLE_IMGSTORE_H_ */
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -36,7 +36,7 @@
  * Add an image to the store. The caller owns a reference
  * to the image in the store, and must dereference the image
- * with gaim_imgstore_unref for it to be freed.
+ * with purple_imgstore_unref for it to be freed.
  *
  * @param data		Pointer to the image data.